@@ -7,26 +7,32 @@
 #include <QtDBus>
 #include <QDesktopServices>
 
+#include "providerwindow.h"
+#include "wrplugin.h"
+
 WrSink::WrSink(const PluginInterface *interface) : SinkPlugin(interface) {
     ready = false;
 }
 
 QString WrSink::getText()
 {
-    return "Search with Google";
+    return "Search the Web";
 }
 
 void WrSink::clickAction(QWidget *parentWindow) {
-    QString uri = "http://www.google.no/search?q=" + QUrl::toPercentEncoding(barcodeText);
-    QDBusInterface *interface = new QDBusInterface("com.nokia.osso_browser","/com/nokia/osso_browser/request","com.nokia.osso_browser");
-    interface->call("open_new_window",uri);
+    ProviderWindow *win = new ProviderWindow(parentWindow, plugin);
+    win->show();
 }
 
 void WrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
     ready = true;
-    this->barcodeText = barcodeData;
+    plugin->barcodeText = barcodeData;
 }
 
 bool WrSink::isReady() {
     return ready;
 }
+
+void WrSink::setPlugin(WrPlugin *plugin) {
+    this->plugin = plugin;
+}
